package com.cib.fintech.dfp.open.sdk;

import com.cib.fintech.dfp.open.sdk.config.Configure;
import com.cib.fintech.dfp.open.sdk.config.KeyConfigure;
import com.cib.fintech.dfp.open.sdk.enums.KeySignTypeEnum;
import com.cib.fintech.dfp.open.sdk.enums.ReqMethodEnum;
import com.cib.fintech.dfp.open.sdk.enums.RespSignAlgorithmEnum;

import java.util.HashMap;
import java.util.Map;

/**
 * 示例类
 * <p>
 * 注意：该类仅供参考学习，请不要将该类直接包含在开发者代码中
 * 重要：各传入参数SDK都不作任何检查、过滤，请务必在传入前进行安全检查或过滤，务必保证传入参数的安全性，否则会导致安全问题
 */
public class Example {

    public static void main(String[] args) {
        Example example = new Example();

        // 【1.设置SDK中应用密钥信息,需在项目启动时完成赋值】
        example.keyConfigureInit();

        // 设置是否测试环境，true连接测试环境，false连接生产环境
        Configure.setDevEnv(true);

        // 按需求调用对应方法，传入keyId区分应用配置
        String response = example.execSdk("KYONLYFORTEST012345678");

        System.out.println(response);
    }

    /**
     * 设置SDK中应用密钥信息
     * <p>
     * 注意：需在项目启动时完成赋值
     * 本代码值仅为示例，实际使用请替换为开发者申请的keyId及密钥
     */
    public void keyConfigureInit() {

        Map<String, KeyConfigure> keyConfigures = Configure.getKeyConfigures();

        // 应用ID，为KY字母开头的字符串，区分大小写
        String keyId = "KYONLYFORTEST012345678";

        // 请求报文签名私钥，需严格保密，建议使用配置文件或其他方式进行存储
        String priKey = "AK7JUorRStFAwM1+BXiHefwmCOZXjVU42b6Oa5JFf5Y7";

        // 响应报文验签公钥
        String respPubKey = "BAQl3uq+FxAGi1/vAZpWyBhdTqBUcenUm8jdPl59XHOeyFkSU3obseTJOTms7lfl0rFALHVTrOmV39N97Z2ZOVI=";

        // 字段加密密钥
        String reqParamEncryptKey = "9A9A4QyNz/pc8kZZXzhXOQ==";

        // keySignTypeEnum 请求签名算法
        // respSignSwitch 响应报文验签开关，true将进行验签，false不进行验签
        // respSignAlgorithmEnum 响应报文验签算法
        KeyConfigure keyConfigure = new KeyConfigure();
        keyConfigure.setKeyId(keyId);
        keyConfigure.setPriKey(priKey);
        keyConfigure.setRespPubKey(respPubKey);
        keyConfigure.setReqParamEncryptKey(reqParamEncryptKey);
        keyConfigure.setKeySignType(KeySignTypeEnum.SM3WITHSM2);
        keyConfigure.setRespSignSwitch(true);
        keyConfigure.setRespSignAlgorithm(RespSignAlgorithmEnum.SM3WITHSM2);

        // 灰度发布配置
        // GrayConfigure grayConfigure = new GrayConfigure();
        // grayConfigure.setKey("wkroute");
        // grayConfigure.setValue("graytest");
        // keyConfigure.setGrayConfigure(grayConfigure);

        // CFCA证书配置（设置CFCA私钥证书全路径文件名、私钥保护密码以及签名算法）
        //        keyConfigure
        //                .setCfcaProperties("C:/Users/cibfintech/Desktop/test.pfx", "WjXcgOQr", KeySignTypeEnum
        //                .SHA256WITHRSA);

        // 用户token认证源为“企业客户授权认证”时配置
//                keyConfigure.setEnterpriseBearer("1117", "PD4gW2jjoeDzeEdwLbPMFGTN", "123456789");

        keyConfigures.put(keyId, keyConfigure);

        Configure.setKeyConfigures(keyConfigures);
    }

    /**
     * 通用请求接口（非文件）
     *
     * @param keyId 应用ID
     * @return 响应报文
     */
    public String execSdk(String keyId) {

        // 【2.准备请求参数】
        // 开发者根据API文档，准备不同的参数集合。headParams-头部信息请求参数、urlParams-URL请求参数、bodyParams-BODY请求参数
        Map<String, String> bodyParams = new HashMap<String, String>(8);
        bodyParams.put("stringParam", "Hello World");
        bodyParams.put("intParam", "111");
        bodyParams.put("byteParam", "1");
        bodyParams.put("shortParam", "1111");
        bodyParams.put("longParam", "111111111");
        bodyParams.put("floatParam", "111.111");
        bodyParams.put("doubleParam", "111.111111");
        bodyParams.put("boolParam", "false");
        bodyParams.put("charParam", "A");

        bodyParams.put("mockBean[0].intParam", "111");
        bodyParams.put("mockBean[0].stringParam", "ascb");

        bodyParams.put("stringList[0]", "stringList0");
        bodyParams.put("stringList[1]", "stringList1");

        bodyParams.put("mockBeanMap[0].intParam", "111");
        bodyParams.put("mockBeanMap[0].doubleParam", "111.111");
        bodyParams.put("mockBeanMap[0].stringParam", "AAAAA");
        bodyParams.put("mockBeanMap[1].intParam", "222");
        bodyParams.put("mockBeanMap[1].doubleParam", "222.222");
        bodyParams.put("mockBeanMap[1].stringParam", "BBBBB");

        bodyParams.put("mockBeanList[0].intParam", "111");
        bodyParams.put("mockBeanList[0].doubleParam", "111.111");
        bodyParams.put("mockBeanList[0].stringParam", "group1/M00/97/68/CmAFGVpd3CGAREPDAAAECO1Nr3I123.txt");
        bodyParams.put("mockBeanList[1].intParam", "222");
        bodyParams.put("mockBeanList[1].doubleParam", "222.222");
        bodyParams.put("mockBeanList[1].stringParam", "group2/M00/97/68/CmAFGVpd3CGAREPDAAAECO1Nr3I123.txt");

        // 需要加密的字段值处理示例（请参阅对应接口文档，并按实际情况使用）
        // try {
        //     bodyParams.put("key", SymmetricEncrypt.aesEncrypt("value","9A9A4QyNz/pc8kZZXzhXOQ=="));
        // } catch (Exception e) {
        //     // 如果字段加密密钥或字段值设置错误，需要处理情况
        //     e.printStackTrace();
        // }

        // 【3.调用SDK方法】
        // 传入请求资源URI、请求方法，以及各位置的参数
        String response = OpenSdk.gatewayWithKeyId("/api/testApi", ReqMethodEnum.POST, null, null, bodyParams, keyId);

        return response;
    }

    /**
     * 通用请求接口（非文件），json
     *
     * @param keyId 应用ID
     * @return 响应报文
     */
    public String execJsonSdk(String keyId) {

        // 【2.准备请求参数】
        // 开发者根据API文档，准备不同的参数集合。headParams-头部信息请求参数、urlParams-URL请求参数、bodyJson-BODY请求参数JSON字符串
        String bodyJson = "{\"key\":\"value\"}";

        // 需要加密的字段值处理示例（请参阅对应接口文档，并按实际情况使用）
        // try {
        //     JSONObject bodyJson = new JSONObject();
        //     bodyJson.put("key", SymmetricEncrypt.aesEncrypt("value","9A9A4QyNz/pc8kZZXzhXOQ=="));
        // } catch (Exception e) {
        //     // 如果字段加密密钥或字段值设置错误，需要处理情况
        //     e.printStackTrace();
        // }

        // 【3.调用SDK方法】
        // 传入请求资源URI、请求方法，以及各位置的参数
        String response = OpenSdk.gatewayJsonWithKeyId("/api/testApi", ReqMethodEnum.POST, null, null, bodyJson, keyId);

        return response;
    }

    /**
     * 文件下载接口
     * <p>
     * 该请求用于下载文件，filePath 文件存储路径
     *
     * @param keyId 应用ID
     * @return 响应报文
     */
    public String downloadFile(String keyId) {

        // 【2.准备请求参数】
        // 文件ID
        String fileId = "group1/M00/A2/19/CmAFGVppoA2AII5mAAAECO1Nr3I.a914b6";

        // 文件存储路径
        String filePath = "C:\\Users\\cibfintech\\Desktop\\test.txt";

        // 【3.调用SDK方法】
        String response = OpenSdk.downloadFileWithKeyId(fileId, filePath, keyId);

        return response;
    }

    /**
     * 文件上传接口
     * <p>
     * 该请求用于上传文件，filePath 文件路径
     *
     * @param keyId 应用ID
     * @return 响应报文
     */
    public String uploadFile(String keyId) {

        // 【2.准备请求参数】
        // 待上传文件路径
        String filePath = "C:\\Users\\cibfintech\\Desktop\\test.txt";

        // 【3.调用SDK方法】
        String response = OpenSdk.uploadFileWithKeyId(filePath, keyId);

        return response;
    }

    /**
     * 公钥查询接口
     * <p>
     * 该请求用于查询公钥（如遇验签失败问题，可尝试调用该接口用于排除密钥、算法不一致问题）
     *
     * @param keyId 应用ID
     * @return 响应报文
     */
    public String queryPubKey(String keyId) {

        // 【调用SDK方法】
        String response = OpenSdk.gatewayWithKeyId("/api/open/queryPubKey", ReqMethodEnum.GET, null, null, null, keyId);

        return response;
    }
}