package com.cib.fintech.dfp.open.sdk.config;

import com.cib.fintech.dfp.open.sdk.enums.KeySignTypeEnum;
import com.cib.fintech.dfp.open.sdk.enums.RespSignAlgorithmEnum;

import java.util.HashMap;
import java.util.Map;

/**
 * 开放银行平台配置类
 * <p>
 * 这里存放所有配置，开发者可以扩展该类
 * 注意：请根据采用的配置方式调用OpenSdk类中对应的方法
 * 1.采用单应用配置方式时，请务必配置该类中的变量，如keyId等
 * 2.采用多应用配置方式时，请务必配置该类中的keyConfigures
 *
 * @author zengminghua
 */
public class Configure {

    /********************************************** ↓ 开发者不可修改 ↓ *************************************/

    /**
     * 开放银行平台生产环境地址，无需修改
     */
    public static final String PROD_URL = "https://open.cibfintech.com";

    /*********************************************** ↓ 开发者可修改 ↓ **************************************/

    /**
     * 是否测试环境开关，true连接测试环境，false连接生产环境
     */
    private static boolean devEnv = true;

    /**
     * 开放银行平台测试环境地址，可根据需要修改
     */
    private static String devUrl = "https://open.test.cibfintech.com";

    /**
     * 应用ID，为KY字母开头的字符串，区分大小写
     */
    private static String keyId = "KYONLYFORTEST012345678";

    /**
     * 请求报文签名私钥，需严格保密，建议使用配置文件或其他方式进行存储
     */
    private static String priKey = "AK7JUorRStFAwM1+BXiHefwmCOZXjVU42b6Oa5JFf5Y7";

    /**
     * 响应报文验签公钥
     */
    private static String respPubKey = "BAQl3uq+FxAGi1/vAZpWyBhdTqBUcenUm8jdPl59XHOeyFkSU3obseTJOTms7lfl0rFALHVTrOmV39N97Z2ZOVI=";

    /**
     * 字段加密密钥
     */
    private static String reqParamEncryptKey = "9A9A4QyNz/pc8kZZXzhXOQ==";

    /**
     * 请求签名算法
     */
    private static KeySignTypeEnum keySignType = KeySignTypeEnum.SM3WITHSM2;

    /**
     * 响应报文验签开关，true将进行验签，false不进行验签
     */
    private static boolean respSignSwitch = false;

    /**
     * 响应报文验签算法
     */
    private static RespSignAlgorithmEnum respSignAlgorithm = RespSignAlgorithmEnum.SM3WITHSM2;

    /**
     * HTTP通讯类，如需使用自己的类库，请修改该值
     */
    private static String httpsRequestClassName = "com.cib.fintech.dfp.open.sdk.common.HttpsPostRequest";

    /**
     * 多应用配置方式时，创建KeyConfigure对象存入map中。示例：map{key=keyId,value=keyConfigure}
     */
    private static Map<String, KeyConfigure> keyConfigures = new HashMap<>(8);

    /**
     * 双向认证证书文件存放路径，不为空将开启双向认证
     * 该路径下证书文件名格式要求：{keyId}.p12，如KYONLYFORTEST012345678.p12
     */
    private static String certPath = null;

    /**
     * 双向认证证书私钥的保护密码，用于提取证书私钥。双向认证开启时必须设置该项
     */
    private static String certProtectionPwd = null;

    /**
     * 灰度发布标识参数
     */
    private static GrayConfigure grayConfigure = null;

    /*****************************************************************************************/

    private static final Object GET_KEYCONFIGURE_LOCK = new Object();

    public static String getKeyId() {
        return keyId;
    }

    public static void setKeyId(String keyId) {
        Configure.keyId = keyId;
    }

    public static String getPriKey() {
        if (priKey.startsWith("-----BEGIN PRIVATE KEY-----")) {
            priKey = priKey.replace("-----BEGIN PRIVATE KEY-----", "").replace("-----END PRIVATE KEY-----", "");
        }
        return priKey;
    }

    public static void setPriKey(String priKey) {
        Configure.priKey = priKey;
    }

    public static KeySignTypeEnum getKeySignType() {
        return keySignType;
    }

    public static void setKeySignType(KeySignTypeEnum keySignType) {
        Configure.keySignType = keySignType;
    }

    public static boolean isRespSignSwitch() {
        return respSignSwitch;
    }

    public static void setRespSignSwitch(boolean respSignSwitch) {
        Configure.respSignSwitch = respSignSwitch;
    }

    public static RespSignAlgorithmEnum getRespSignAlgorithm() {
        return respSignAlgorithm;
    }

    public static void setRespSignAlgorithm(RespSignAlgorithmEnum respSignAlgorithm) {
        Configure.respSignAlgorithm = respSignAlgorithm;
    }

    public static String getRespPubKey() {
        return respPubKey;
    }

    public static void setRespPubKey(String respPubKey) {
        Configure.respPubKey = respPubKey;
    }

    public static String getReqParamEncryptKey() {
        return reqParamEncryptKey;
    }

    public static void setReqParamEncryptKey(String reqParamEncryptKey) {
        Configure.reqParamEncryptKey = reqParamEncryptKey;
    }

    public static String getHttpsRequestClassName() {
        return httpsRequestClassName;
    }

    public static void setHttpsRequestClassName(String httpsRequestClassName) {
        Configure.httpsRequestClassName = httpsRequestClassName;
    }

    public static boolean isDevEnv() {
        return devEnv;
    }

    public static void setDevEnv(boolean devEnv) {
        Configure.devEnv = devEnv;
    }

    public static String getDevUrl() {
        return devUrl;
    }

    public static void setDevUrl(String devUrl) {
        Configure.devUrl = devUrl;
    }

    public static Map<String, KeyConfigure> getKeyConfigures() {
        return keyConfigures;
    }

    public static void setKeyConfigures(Map<String, KeyConfigure> keyConfigures) {
        Configure.keyConfigures = keyConfigures;
    }

    public static String getCertPath() {
        return certPath;
    }

    public static void setCertPath(String certPath) {
        Configure.certPath = certPath;
    }

    public static String getCertProtectionPwd() {
        return certProtectionPwd;
    }

    public static void setCertProtectionPwd(String certProtectionPwd) {
        Configure.certProtectionPwd = certProtectionPwd;
    }

    public static GrayConfigure getGrayConfigure() {
        return grayConfigure;
    }

    public static void setGrayConfigure(GrayConfigure grayConfigure) {
        Configure.grayConfigure = grayConfigure;
    }

    /**
     * 采用单应用配置方式时,获取配置对象方法
     *
     * @return keyConfigure
     */
    public static KeyConfigure getKeyConfigure() {
        KeyConfigure keyConfigure = keyConfigures.get(keyId);
        if (null != keyConfigure) {
            return keyConfigure;
        }
        synchronized (GET_KEYCONFIGURE_LOCK) {
            keyConfigure = keyConfigures.get(keyId);
            if (null != keyConfigure) {
                return keyConfigure;
            }
            keyConfigure = new KeyConfigure();
            keyConfigure.setKeyId(keyId);
            keyConfigure.setPriKey(priKey);
            keyConfigure.setKeySignType(keySignType);
            keyConfigure.setRespSignSwitch(respSignSwitch);
            keyConfigure.setRespSignAlgorithm(respSignAlgorithm);
            keyConfigure.setRespPubKey(respPubKey);
            keyConfigure.setReqParamEncryptKey(reqParamEncryptKey);
            keyConfigure.setCertProtectionPwd(certProtectionPwd);
            keyConfigure.setGrayConfigure(grayConfigure);
            keyConfigures.put(keyId, keyConfigure);
        }
        return keyConfigure;
    }

}
