package com.cib.fintech.dfp.open.sdk.util;

import com.cib.fintech.dfp.open.sdk.exception.SdkExType;
import com.cib.fintech.dfp.open.sdk.exception.SdkException;

import java.io.*;
import java.security.MessageDigest;

/**
 * 文件工具
 *
 * @author zengminghua
 */
public class FileUtil {

    public static final char[] HEX_CHAR = {
            '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'a', 'b', 'c', 'd', 'e', 'f'};

    /**
     * @param filePath 文件路径
     * @return file bytes
     * @throws IOException 读取文件错误
     */
    public static byte[] readFileByBytes(String filePath) throws IOException {
        File file = new File(filePath);
        if (!file.exists()) {
            throw new FileNotFoundException(filePath);
        }

        ByteArrayOutputStream baos = new ByteArrayOutputStream(((int) file.length()));
        BufferedInputStream in = null;
        try {
            in = new BufferedInputStream(new FileInputStream(file));
            int bufSize = 1024;
            byte[] buffer = new byte[bufSize];
            int len;
            while (-1 != (len = in.read(buffer, 0, bufSize))) {
                baos.write(buffer, 0, len);
            }
            return baos.toByteArray();
        } finally {
            try {
                if (in != null) {
                    in.close();
                }
            } catch (IOException e) {
                // e.printStackTrace();
            }
            baos.close();
        }
    }

    /**
     * 计算文件的特征值
     * <p>
     * 支持的算法如："MD2", "MD5", "SHA-1", "SHA-256", "SHA-384", "SHA-512"
     *
     * @param filePath  文件路径
     * @param algorithm 算法
     * @return hashValue 特征值
     */
    public static String fileHash(String filePath, String algorithm) throws Exception {
        MessageDigest messagedigest = null;
        try {
            messagedigest = MessageDigest.getInstance(algorithm);

            InputStream fis = null;
            try {
                fis = new FileInputStream(filePath);
                byte[] buffer = new byte[1024];
                int numRead = 0;
                while ((numRead = fis.read(buffer)) > 0) {
                    messagedigest.update(buffer, 0, numRead);
                }
            } catch (Exception ex) {
                // ex.printStackTrace();
            } finally {
                if (fis != null) {
                    fis.close();
                }
            }
        } catch (Exception e) {
            SdkException ex = new SdkException(SdkExType.FILE_ERROR_RESULT);
            return ex.toString();
        }
        return toHexString(messagedigest.digest());
    }

    public static String toHexString(byte[] b) {
        StringBuilder sb = new StringBuilder(b.length * 2);
        for (int i = 0; i < b.length; i++) {
            sb.append(HEX_CHAR[(b[i] & 0xf0) >>> 4]);
            sb.append(HEX_CHAR[b[i] & 0x0f]);
        }
        return sb.toString();
    }

}
